@@ -1,6 +1,7 @@
 #ifndef MAIL_USER_H
 #define MAIL_USER_H
 
+#include "net.h"
 #include "unichar.h"
 #include "mail-storage-settings.h"
 
@@ -12,14 +13,24 @@ struct mail_user;
 
 struct mail_user_vfuncs {
 	void (*deinit)(struct mail_user *user);
+	void (*deinit_pre)(struct mail_user *user);
 	void (*stats_fill)(struct mail_user *user, struct stats *stats);
 };
 
+struct mail_user_connection_data {
+	struct ip_addr *local_ip, *remote_ip;
+	in_port_t local_port, remote_port;
+
+	bool secured:1;
+	bool ssl_secured:1;
+};
+
 struct mail_user {
 	pool_t pool;
 	struct mail_user_vfuncs v, *vlast;
 	int refcount;
 
+	struct event *event;
 	/* User's creator if such exists. For example for autocreated shared
 	   mailbox users their creator is the logged in user. */
 	struct mail_user *creator;
@@ -34,7 +45,7 @@ struct mail_user {
 	gid_t gid;
 	const char *service;
 	const char *session_id;
-	struct ip_addr *local_ip, *remote_ip;
+	struct mail_user_connection_data conn;
 	const char *auth_token, *auth_user;
 	const char *const *userdb_fields;
 	/* Timestamp when this session was initially created. Most importantly
@@ -62,41 +73,41 @@ struct mail_user {
 
 	/* User doesn't exist (as reported by userdb lookup when looking
 	   up home) */
-	unsigned int nonexistent:1;
+	bool nonexistent:1;
 	/* Either home is set or there is no home for the user. */
-	unsigned int home_looked_up:1;
+	bool home_looked_up:1;
 	/* User is anonymous */
-	unsigned int anonymous:1;
+	bool anonymous:1;
 	/* This is an autocreated user (e.g. for shared namespace or
 	   lda raw storage) */
-	unsigned int autocreated:1;
+	bool autocreated:1;
 	/* mail_user_init() has been called */
-	unsigned int initialized:1;
+	bool initialized:1;
 	/* The initial namespaces have been created and
 	   hook_mail_namespaces_created() has been called. */
-	unsigned int namespaces_created:1;
+	bool namespaces_created:1;
 	/* SET_STR_VARS in user's all settings have been expanded.
 	   This happens near the beginning of the user initialization,
 	   so this is rarely needed to be checked. */
-	unsigned int settings_expanded:1;
+	bool settings_expanded:1;
 	/* Shortcut to mail_storage_settings.mail_debug */
-	unsigned int mail_debug:1;
+	bool mail_debug:1;
 	/* If INBOX can't be opened, log an error, but only once. */
-	unsigned int inbox_open_error_logged:1;
+	bool inbox_open_error_logged:1;
 	/* Fuzzy search works for this user (FTS enabled) */
-	unsigned int fuzzy_search:1;
+	bool fuzzy_search:1;
 	/* We're running dsync */
-	unsigned int dsyncing:1;
+	bool dsyncing:1;
 	/* Failed to create attribute dict, don't try again */
-	unsigned int attr_dict_failed:1;
+	bool attr_dict_failed:1;
 	/* We're deinitializing the user */
-	unsigned int deinitializing:1;
+	bool deinitializing:1;
 	/* Enable administrator user commands for the user */
-	unsigned int admin:1;
+	bool admin:1;
 	/* Enable all statistics gathering */
-	unsigned int stats_enabled:1;
+	bool stats_enabled:1;
 	/* This session was restored (e.g. IMAP unhibernation) */
-	unsigned int session_restored:1;
+	bool session_restored:1;
 };
 
 struct mail_user_module_register {
@@ -111,11 +122,13 @@ extern struct mail_user_module_register mail_user_module_register;
 extern struct auth_master_connection *mail_user_auth_master_conn;
 extern const struct var_expand_func_table *mail_user_var_expand_func_table;
 
-struct mail_user *mail_user_alloc(const char *username,
+struct mail_user *mail_user_alloc(struct event *parent_event,
+				  const char *username,
 				  const struct setting_parser_info *set_info,
 				  const struct mail_user_settings *set);
 struct mail_user *
-mail_user_alloc_nodup_set(const char *username,
+mail_user_alloc_nodup_set(struct event *parent_event,
+			  const char *username,
 			  const struct setting_parser_info *set_info,
 			  const struct mail_user_settings *set);
 /* Returns -1 if settings were invalid. */
@@ -133,8 +146,7 @@ struct mail_user *mail_user_find(struct mail_user *user, const char *name);
 
 /* Specify mail location %variable expansion data. */
 void mail_user_set_vars(struct mail_user *user, const char *service,
-			const struct ip_addr *local_ip,
-			const struct ip_addr *remote_ip);
+			const struct mail_user_connection_data *conn);
 /* Return %variable expansion table for the user. */
 const struct var_expand_table *
 mail_user_var_expand_table(struct mail_user *user);
@@ -151,13 +163,20 @@ int mail_user_get_home(struct mail_user *user, const char **home_r);
    The file prefix doesn't contain any uniqueness. */
 void mail_user_set_get_temp_prefix(string_t *dest,
 				   const struct mail_user_settings *set);
+/* Returns 1 on success, 0 if lock_secs is reached, -1 on error */
+int mail_user_lock_file_create(struct mail_user *user, const char *lock_fname,
+			       unsigned int lock_secs,
+			       struct file_lock **lock_r, const char **error_r);
 
 /* Returns TRUE if plugin is loaded for the user. */
 bool mail_user_is_plugin_loaded(struct mail_user *user, struct module *module);
 /* If name exists in plugin_envs, return its value. */
 const char *mail_user_plugin_getenv(struct mail_user *user, const char *name);
+bool mail_user_plugin_getenv_bool(struct mail_user *user, const char *name);
 const char *mail_user_set_plugin_getenv(const struct mail_user_settings *set,
 					const char *name);
+bool mail_user_set_plugin_getenv_bool(const struct mail_user_settings *set,
+				      const char *name);
 
 /* Add more namespaces to user's namespaces. The ->next pointers may be
    changed, so the namespaces pointer will be updated to user->namespaces. */
